Examples & Tests
================

A series of examples to illustrate the usage of **pybdsim**. These also form
the basis of the test suite to ensure stable development and record any changes.
Each example is self contained and instructions are provided both in this
documentation and in the .rst files beside the each example.

.. toctree::
   :maxdepth: 2

   1_builder/1_builder
   2_convert/2_convert
   3_optics/3_optics
   4_uproot/4_uproot